.. _core_roadmap_2.15:

*****************
Ansible-core 2.15
*****************

.. contents::
   :local:

Release Schedule
================

Expected
--------

PRs must be raised well in advance of the dates below to have a chance of being included in this ansible-core release.

.. note:: Dates subject to change.

Development Phase
^^^^^^^^^^^^^^^^^

The ``milestone`` branch will be advanced at the start date of each development phase.

- 2022-10-17 Development Phase 1
- 2022-12-19 Development Phase 2
- 2023-02-20 Development Phase 3

Release Phase
^^^^^^^^^^^^^

- 2023-03-31 Feature Freeze (and ``stable-2.15`` branching from ``devel``)
  No new functionality (including modules/plugins) to any code

- 2023-04-03 Beta 1

- 2023-04-24 Release Candidate 1

- 2023-05-15 Release

.. note:: The beta and release candidate schedules allow for up to 3 releases on a weekly schedule depending on the necessity of creating a release.

Release Manager
===============

 Ansible Core Team

Planned work
============

* Proxy prompting over queue from forks

Delayed work
============

The following work has been delayed and retargeted for a future release:

* Data Tagging
